---
title: Analysis of federal .gov domains, 2015 edition
description: A quick analysis of the technology and capabilities that power each federal .gov domain such as non-www, SSL, and IPv6 support, or what server/cms they use
---

In [2011](https://ben.balter.com/2011/09/07/analysis-of-federal-executive-domains/) and then again in [2014](https://ben.balter.com/2014/07/07/analysis-of-federal-executive-domains-part-deux/) I used
[a small tool](https://github.com/benbalter/site-inspector) that I wrote to crawl every site on the [publicly available list of Federal Executive .gov domains](https://github.com/GSA/data/tree/gh-pages/dotgov-domains) to get a better sense of the state of federal IT, at least when it comes to agencies' public-facing web presence. This weekend, I decided to resurrect that effort, with the recently updated list of .gov domains, and with a more finely tuned version of the [open source Site Inspector tool](https://github.com/benbalter/site-inspector), thanks to some contributions from [Eric Mill](https://konklone.com/).

You can always compare them to the original [2011](https://ben.balter.com/2011/09/07/analysis-of-federal-executive-domains/) or [2014](https://ben.balter.com/2014/07/07/analysis-of-federal-executive-domains-part-deux/) crawls, or [browse the entire dataset for yourself](https://dotgov-browser.herokuapp.com){: data-proofer-ignore="true" }, but here are some highlights of what I found:

* 1177 of those domains [are live](https://dotgov-browser.herokuapp.com/domains?up=true){: data-proofer-ignore="true" } (about 86%, up from 83% last year, and 73% originally)
* Of those live domains [only 75% are reachable without the `www.` prefix](https://dotgov-browser.herokuapp.com/domains?root=true&up=true){: data-proofer-ignore="true" }, down from 83% last year
* [722 sites](https://dotgov-browser.herokuapp.com/domains?ipv6=true){: data-proofer-ignore="true" } return an `AAAA` record, the first step towards IPv6 compliance (up from 64 last year, and 10 before that, more than a 10x increase)
* [344 sites](https://dotgov-browser.herokuapp.com/domains?https=true){: data-proofer-ignore="true" } are reachable via HTTPS (stagnant at one in four from last year), and like last year, [only one in ten](https://dotgov-browser.herokuapp.com/domains?canonically_https=true&https=true){: data-proofer-ignore="true" } enforce it.
* 87% of sites have no decreeable CMS (the same as last year), with Drupal leading the pack with [123 sites](https://dotgov-browser.herokuapp.com/domains?content_management_system=drupal){: data-proofer-ignore="true" }, WordPress with [29 sites](https://dotgov-browser.herokuapp.com/domains?content_management_system=wordpress){: data-proofer-ignore="true" } (double from last year), and Joomla powering [8](https://dotgov-browser.herokuapp.com/domains?content_management_system=joomla){: data-proofer-ignore="true" } (up one from last year)
* Just shy of 40% of sites advertise that they are powered by open source server software (e.g. Apache, Nginx), up from about a third last year, with about one in five sites responding that they are powered by closed source software (e.g., Microsoft, Oracle, Sun)
* [61 sites](https://dotgov-browser.herokuapp.com/domains?server=Microsoft-IIS%2F6.0){: data-proofer-ignore="true" } are still somehow running IIS 6.0 (down from 74 last year), a 10+ year old server
* HHS is still the biggest perpetrator of domain sprawl with [117 domains](https://dotgov-browser.herokuapp.com/domains?agency=department-of-health-and-human-services){: data-proofer-ignore="true" } (up from 110 last year), followed by GSA ([104](https://dotgov-browser.herokuapp.com/domains?agency=general-services-administration){: data-proofer-ignore="true" }, down from 105), Treasury ([95](https://dotgov-browser.herokuapp.com/domains?agency=department-of-the-treasury){: data-proofer-ignore="true" }, up from 92), and Interior ([86](https://dotgov-browser.herokuapp.com/domains?agency=department-of-the-interior){: data-proofer-ignore="true" }, down from 89)
* Only [67](https://dotgov-browser.herokuapp.com/domains?slash_developer=true&proper_404s=true){: data-proofer-ignore="true" } domains have a `/developer` page, [99](https://dotgov-browser.herokuapp.com/domains?slash_data=true&proper_404s=true){: data-proofer-ignore="true" } have a `/data` page, and [74](https://dotgov-browser.herokuapp.com/domains?data_dot_json=true&proper_404s=true){: data-proofer-ignore="true" } have a `/data.json` file, all significantly down from past years, due to more accurate means of calculation, which brings us to
* [255](https://dotgov-browser.herokuapp.com/domains?proper_404s=false){: data-proofer-ignore="true" }, or just shy of 20% of domains, don't properly return "page not found" or 404 errors, meaning if you programmatically request their `/data.json` file (or any other non-existent URL), the server will tell you that it's found the requested file, but really respond with a human-readable "page not found" error, making machine readability especially challenging

**Edit (5/12/2015)**: As @konklone [properly points out](https://github.com/benbalter/benbalter.github.com/pull/258/files#r30093194){: data-proofer-ignore="true" } the list now includes legislative and judicial .gov domains, and thus isn't limited to just to federal executive `.govs`.

As I've said in past years, math's never been my strong point, so I highly encourage you to check my work. You can browse the full results at [dotgov-browser.herokuapp.com](https://dotgov-browser.herokuapp.com){: data-proofer-ignore="true" } or check an individual site (.gov or otherwise) at [site-inspector.herokuapp.com](https://site-inspector.herokuapp.com). The source code for all tools used, is available [on GitHub](https://github.com/benbalter/site-inspector). If you find an error, I encourage you to [open an issue](https://github.com/benbalter/site-inspector/issues/new) or [submit a pull request](https://guides.github.com/introduction/flow/).
