---
title: Problems, not solutions
description: If there's one thing that defines the shift from another technology role to Product Management, it's the shift from thinking in terms of solutions to thinking in terms of problems.
---

If there's one thing that defines the shift from another technology role to Product Management, it's the shift from thinking in terms of solutions to thinking in terms of problems.

As Engineers (or just about any other technical profession), we're trained to think in terms of solutions (what feature to build, how to build them, subsequent improvements, etc.), but given a sufficiently defined problem, the solution is often the easy part (even if the implementation itself may be technically complex). The real challenge lies in understanding customers' true needs (not just their stated ones), defining and prioritizing user problems, and evaluating potential solutions to determine the right one (and where your efforts can have the biggest impact).

### Jobs to be done

Ultimately, customers [hire products to do a job](https://hbr.org/2016/09/know-your-customers-jobs-to-be-done). Imagine a customer comes to you asking for a 1/4" drill (a solution). Their stated problem may be the need for a 1/4" hole, but what they're really after is the ability to hang a picture (which could be accomplished a number of ways - a hammer and nail, 3M Command strips, etc.). Going further, the underlying customer problem may really be the desire to remember milestones or important people in their life, which may be best served by an app on their phone or a digital picture frame which avoids the need to hang something altogether. You can build the world's best drill, but it may be the right solution to the wrong problem.

Are holes in the wall a concern? The need to also purchase a hammer and nail? Potentially hitting their finger as they hang it? The photo being hung crooked? Positioning on the wall? The ability to move the picture without damage? Which do they value more? How often do they hang pictures? How many photos are they hanging? How heavy are the frames? The list of potential variables, and thus customer concerns (or unexpected consequences to the wrong solution), is often endless.

As a Product Manager, even when customers come to you with desired solutions (or you intuitively have one in mind), it pays to start by explicitly enumerating the problems you're trying to solve (and the customers you're trying to solve them for). You'd be surprised how many different ways the same problem(s) can be solved or how the right solution can solve multiple problems for the customer (or the wrong one can create even more).

Worse yet, you may find you're implementing an intellectually interesting solution in search of a problem. If you're truly building a product for your users, everything you do should stem from a user need.

### Why over What

The other way to think about talking in terms of problems instead of solutions is that you should spend more time talking about the "why", than you spend talking about the "what", or at least translating between the two.

If your team agrees its goal is to do X, it's natural that you'll spend more time discussing and tracking what you need to do to get to X, than what X does. While managing work may be part of a PM's role, it's important that the language you use constantly frames things through a lens of end user value. Put another way, throughout the development process, you should serve as the voice of the user, advocating for their needs at every step.

If you spend months refactoring an app to make it "right", to utilize an exciting new technology, or to make it easier to maintain internally, it's easy to talk about all the work you're doing, but if at the end, the only user-facing change is a small bug fix, slightly better uptime, or slightly faster responses,[^1] it's hard to describe the "why", other than "this is better", especially in terms of the effort expended and other potential features foregone. On the flip-side, if a one- or two-line change can have immense user impact, it's boring to talk about the "what", but you could talk about the "why" for hours.

As a Product Manager, your job is to optimize for those (ideally boring) low effort, high impact initiatives, that improve the experience for users and give you the best value in terms of time and effort, and the easiest way is to do that is to focus on why you're doing things, and who you're doing them for, counterbalanced by the effort required, not the other way around.

### What problem are we solving?

As cliché as it may be in some circles, one of the most important questions that you can ask as a Product Manager (of yourself or others), is "what problem are we trying to solve?". I can't tell you the number of times the answer is, alarmingly, "that's a good question…", even among projects that were well underway. If you don't know what user problem you're solving — what jobs your doing for the user — and by extension, what end-user-value you're seeking to deliver — then you're just doing work for the sake of doing work, and not to better your product or the customer experience.

As technologists, the solutions are the fun part. Many of us got into the field because we love building things or overcoming complex technical challenges. [Great PMs don't spend their time on solutions](https://www.intercom.com/blog/great-product-managers-dont-spend-time-on-solutions/). Despite the most visible or tangible artifact being what we ultimately ship, the most valuable contribution a product manager can make is properly framing the problem at the onset, to ensure we're delivering the right solution, to the right customer, at the right time.

[^1]: Performance, uptime, quality, and reliability are and should be seen as features. As such, they should be prioritized like any other feature, and evaluated through the lens of user impact.
